==> gottet-1.0.6-src.tar.bz2: gottet-1.0.6/translations/gottet_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="89"/>
        <source>End the current game?</source>
        <translation>¿Quiere finalizar el juego actual?</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="175"/>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;En pausa&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Pulse para continuar la partida.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="403"/>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Partida terminada&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Pulse para comenzar una partida nueva.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie esta aplicación para que el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Gottet Scores</source>
        <translation>Puntuaciones de Gottet</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="56"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <location filename="../src/window.cpp" line="221"/>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Click to start a new game.</source>
        <translation>Pulse para iniciar una partida nueva.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>&amp;New</source>
        <translation>&amp;Nueva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <location filename="../src/window.cpp" line="115"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="115"/>
        <source>&amp;Resume</source>
        <translation>&amp;Reanudar</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Scores</source>
        <translation>P&amp;untuaciones</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación…</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="125"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="126"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="127"/>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="141"/>
        <source>Next Piece</source>
        <translation>Pieza siguiente</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>Removed Lines</source>
        <translation>Líneas eliminadas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>Score</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="220"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>A tetris clone I made for my wife</source>
        <translation>Un clon de Tetris que creé para mi esposa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="223"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="224"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet-1.2.0-src.tar.bz2: gottet-1.2.0/translations/gottet_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>¿Quiere finalizar el juego actual?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;En pausa&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Pulse para continuar la partida.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Partida terminada&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Pulse para comenzar una partida nueva.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie esta aplicación para que el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Pulse para iniciar una partida nueva.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Partida</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nueva</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>P&amp;untuaciones</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Pieza siguiente</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Líneas eliminadas</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
